Changelog
=========


* :release:`0.4.6 <2015-12-12>`
* :bug:`0` Fix NumPy 1.10 casting error
* :bug:`0` Add Python 3.5 compatibility

* :release:`0.4.5 <2015-12-12>`
* :bug:`0` Fix Readthedocs notebook conversion

* :release:`0.4.1 <2015-08-24>`
* :bug:`0` Fix citation in documentation
* :release:`0.4.0 <2015-08-14>`
* :feature:`0` Implement percolate.hpc module
* :release:`0.3.1 <2015-08-14>`
* :feature:`0` Configure continuous deployment to PyPI with Travis
* :feature:`0` Restructure package development
* :release:`v0.3.0 <2015-08-09>`
* :feature:`0` Configure Travis, Coveralls, Landscape continuous integration
* :release:`v0.2.5 <2015-05-13>`
* :bug:`0` Fix changelog
* :release:`v0.2.4 <2015-05-13>`
* :bug:`9` Fix documentation and move it to github pages
* :release:`v0.2.3 <2015-04-30>`
* :bug:`0` Fix setup.cfg classifiers
* :release:`v0.2.2 <2015-04-30>`
* :bug:`0` Change author email
* :release:`v0.2.1 <2015-04-29>`
* :bug:`0` Update Zenodo DOI
* :release:`v0.2.0 <2015-04-25>`
* :feature:`0` Basic functionality
